window.Gleam.initSearch([{"doc":"datastar","title":"datastar","content":"# DataStar\n\n[![Package Version](https://img.shields.io/hexpm/v/datastar)](https://hex.pm/packages/datastar)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/datastar/)\n\nGleam bindings for 🚀 &lt;https://data-star.dev/&gt;.\n\nThis library provides Gleam functions for building **server sent events (SSE)** in the backend to use with **Datastar**.\n\n```gleam\n[\n  remove_fragments(&quot;#error&quot;)\n  |&gt; remove_fragments_end,\n  merge_fragments(&quot;&lt;span&gt;Hello&lt;/span&gt;&quot;)\n  |&gt; merge_fragments_selector(&quot;#notice&quot;)\n  |&gt; merge_fragments_merge_mode(Inner)\n  |&gt; merge_fragments_end,\n]\n|&gt; events_to_string\n```\n\nThis generates:\n\n```text\nevent: datastar-remove-fragments\ndata: selector #error\n\nevent: datastar-merge-fragments\ndata: mergeMode inner\ndata: selector #notice\ndata: fragments &lt;span&gt;Hello&lt;/span&gt;\n```\n\nAPI documentation at &lt;https://hexdocs.pm/datastar&gt;.\n\nDatastar SSE reference &lt;https://data-star.dev/reference/sse_events&gt;.\n\nTo use this with **wisp**, see &lt;https://hexdocs.pm/datastar_wisp&gt;.\n","url":"index.html"},{"doc":"datastar","title":"Event","content":"pub type Event {\n  EventMergeFragment(MergeFragmentConfig)\n  EventRemoveFragments(RemoveFragmentsConfig)\n  EventMergeSignals(MergeSignalsConfig)\n  EventRemoveSignals(RemoveSignalsConfig)\n  EventExecuteScript(ExecuteScriptConfig)\n}\n SSE Events that can be send to the client\nEventMergeFragment(MergeFragmentConfig)\n\n\nEventRemoveFragments(RemoveFragmentsConfig)\n\n\nEventMergeSignals(MergeSignalsConfig)\n\n\nEventRemoveSignals(RemoveSignalsConfig)\n\n\nEventExecuteScript(ExecuteScriptConfig)\n\n\nSynonyms:\ndatastar.Event\ndatastar Event","url":"datastar.html#Event"},{"doc":"datastar","title":"ExecuteScriptConfig","content":"pub type ExecuteScriptConfig {\n  ExecuteScriptConfig(\n    script: String,\n    options: ExecuteScriptOptions,\n  )\n}\n\nExecuteScriptConfig(\n  script: String,\n  options: ExecuteScriptOptions,\n)\n\n\nSynonyms:\ndatastar.ExecuteScriptConfig\ndatastar ExecuteScriptConfig","url":"datastar.html#ExecuteScriptConfig"},{"doc":"datastar","title":"ExecuteScriptOptions","content":"pub type ExecuteScriptOptions {\n  ExecuteScriptOptions(\n    attributes: List(#(String, String)),\n    auto_remove: Bool,\n    event_id: Option(String),\n    retry: Option(Int),\n  )\n}\n\nExecuteScriptOptions(\n  attributes: List(#(String, String)),\n  auto_remove: Bool,\n  event_id: Option(String),\n  retry: Option(Int),\n)\n\n\nSynonyms:\ndatastar.ExecuteScriptOptions\ndatastar ExecuteScriptOptions","url":"datastar.html#ExecuteScriptOptions"},{"doc":"datastar","title":"MergeFragmentConfig","content":"pub type MergeFragmentConfig {\n  MergeFragmentConfig(\n    fragments: String,\n    options: MergeFragmentOptions,\n  )\n}\n\nMergeFragmentConfig(\n  fragments: String,\n  options: MergeFragmentOptions,\n)\n\n\nSynonyms:\ndatastar.MergeFragmentConfig\ndatastar MergeFragmentConfig","url":"datastar.html#MergeFragmentConfig"},{"doc":"datastar","title":"MergeFragmentOptions","content":"pub type MergeFragmentOptions {\n  MergeFragmentOptions(\n    event_id: Option(String),\n    merge_mode: MergeMode,\n    retry: Option(Int),\n    selector: Option(String),\n    settle_duration: Int,\n    view_transition: Bool,\n  )\n}\n\nMergeFragmentOptions(\n  event_id: Option(String),\n  merge_mode: MergeMode,\n  retry: Option(Int),\n  selector: Option(String),\n  settle_duration: Int,\n  view_transition: Bool,\n)\n\n\nSynonyms:\ndatastar.MergeFragmentOptions\ndatastar MergeFragmentOptions","url":"datastar.html#MergeFragmentOptions"},{"doc":"datastar","title":"MergeMode","content":"pub type MergeMode {\n  Morph\n  Inner\n  Outer\n  Prepend\n  Append\n  Before\n  After\n  UpsertAttributes\n}\n The merge mode used by merge fragments\nMorph\n\n\nInner\n\n\nOuter\n\n\nPrepend\n\n\nAppend\n\n\nBefore\n\n\nAfter\n\n\nUpsertAttributes\n\n\nSynonyms:\ndatastar.MergeMode\ndatastar MergeMode","url":"datastar.html#MergeMode"},{"doc":"datastar","title":"MergeSignalsConfig","content":"pub type MergeSignalsConfig {\n  MergeSignalsConfig(\n    signals: String,\n    options: MergeSignalsOptions,\n  )\n}\n\nMergeSignalsConfig(signals: String, options: MergeSignalsOptions)\n\n\nSynonyms:\ndatastar.MergeSignalsConfig\ndatastar MergeSignalsConfig","url":"datastar.html#MergeSignalsConfig"},{"doc":"datastar","title":"MergeSignalsOptions","content":"pub type MergeSignalsOptions {\n  MergeSignalsOptions(\n    event_id: Option(String),\n    retry: Option(Int),\n    only_if_missing: Bool,\n  )\n}\n\nMergeSignalsOptions(\n  event_id: Option(String),\n  retry: Option(Int),\n  only_if_missing: Bool,\n)\n\n\nSynonyms:\ndatastar.MergeSignalsOptions\ndatastar MergeSignalsOptions","url":"datastar.html#MergeSignalsOptions"},{"doc":"datastar","title":"RemoveFragmentsConfig","content":"pub type RemoveFragmentsConfig {\n  RemoveFragmentsConfig(\n    selector: String,\n    options: RemoveFragmentsOptions,\n  )\n}\n\nRemoveFragmentsConfig(\n  selector: String,\n  options: RemoveFragmentsOptions,\n)\n\n\nSynonyms:\ndatastar.RemoveFragmentsConfig\ndatastar RemoveFragmentsConfig","url":"datastar.html#RemoveFragmentsConfig"},{"doc":"datastar","title":"RemoveFragmentsOptions","content":"pub type RemoveFragmentsOptions {\n  RemoveFragmentsOptions(\n    event_id: Option(String),\n    retry: Option(Int),\n    settle_duration: Int,\n    view_transition: Bool,\n  )\n}\n\nRemoveFragmentsOptions(\n  event_id: Option(String),\n  retry: Option(Int),\n  settle_duration: Int,\n  view_transition: Bool,\n)\n\n\nSynonyms:\ndatastar.RemoveFragmentsOptions\ndatastar RemoveFragmentsOptions","url":"datastar.html#RemoveFragmentsOptions"},{"doc":"datastar","title":"RemoveSignalsConfig","content":"pub type RemoveSignalsConfig {\n  RemoveSignalsConfig(\n    signals: List(String),\n    options: RemoveSignalsOptions,\n  )\n}\n\nRemoveSignalsConfig(\n  signals: List(String),\n  options: RemoveSignalsOptions,\n)\n\n\nSynonyms:\ndatastar.RemoveSignalsConfig\ndatastar RemoveSignalsConfig","url":"datastar.html#RemoveSignalsConfig"},{"doc":"datastar","title":"RemoveSignalsOptions","content":"pub type RemoveSignalsOptions {\n  RemoveSignalsOptions(\n    event_id: Option(String),\n    retry: Option(Int),\n  )\n}\n\nRemoveSignalsOptions(\n  event_id: Option(String),\n  retry: Option(Int),\n)\n\n\nSynonyms:\ndatastar.RemoveSignalsOptions\ndatastar RemoveSignalsOptions","url":"datastar.html#RemoveSignalsOptions"},{"doc":"datastar","title":"event_to_string","content":"pub fn event_to_string(event: Event) -&gt; String\n Takes an `Event` and generates a string to send back to the client\n\n \n remove_fragments(&quot;#target&quot;)\n |&gt; remove_fragments_end\n |&gt; event_to_string\n \n Generates:\n text\n event: datastar-remove-fragments\n data: selector #target\n\n \n\nSynonyms:\ndatastar.event_to_string\ndatastar event_to_string","url":"datastar.html#event_to_string"},{"doc":"datastar","title":"events_to_string","content":"pub fn events_to_string(events events: List(Event)) -&gt; String\n Takes a list of `Event` and generates the string to send to the client\n\n \n [\n   merge_fragments(&quot;&lt;span&gt;Hello&lt;/span&gt;&quot;)\n   |&gt; merge_fragments_end,\n   remove_fragments(&quot;#target&quot;)\n   |&gt; remove_fragments_end,\n ]\n |&gt; events_to_string\n \n Generates:\n text\n event: datastar-merge-fragments\n data: fragments &lt;span&gt;Hello&lt;/span&gt;\n\n event: datastar-remove-fragments\n data: selector #target\n\n \n\nSynonyms:\ndatastar.events_to_string\ndatastar events_to_string","url":"datastar.html#events_to_string"},{"doc":"datastar","title":"execute_script","content":"pub fn execute_script(script: String) -&gt; ExecuteScriptConfig\n Generate a `datastar-execute-script` event\n\n \n execute_script(&quot;window.location = \\&quot;https://data-star.dev\\&quot;&quot;)\n |&gt; execute_script_event_id(&quot;123&quot;)\n |&gt; execute_script_end\n \n Generates\n text\n event: datastar-execute-script\n id: 123\n data: script window.location = \\&quot;https://data-star.dev\\&quot;\n \nSynonyms:\ndatastar.execute_script\ndatastar execute_script","url":"datastar.html#execute_script"},{"doc":"datastar","title":"execute_script_attributes","content":"pub fn execute_script_attributes(\n  config: ExecuteScriptConfig,\n  value: List(#(String, String)),\n) -&gt; ExecuteScriptConfig\n \n |&gt; execute_script_attributes([#(&quot;type&quot;, &quot;text/javascript&quot;)]),\n \n Generates:\n text\n data: attributes type text/javascript\n \nSynonyms:\ndatastar.execute_script_attributes\ndatastar execute_script_attributes","url":"datastar.html#execute_script_attributes"},{"doc":"datastar","title":"execute_script_auto_remove","content":"pub fn execute_script_auto_remove(\n  config: ExecuteScriptConfig,\n  value: Bool,\n) -&gt; ExecuteScriptConfig\n \n |&gt; execute_script_auto_remove(False),\n \n Generates:\n text\n data: autoRemove false\n \nSynonyms:\ndatastar.execute_script_auto_remove\ndatastar execute_script_auto_remove","url":"datastar.html#execute_script_auto_remove"},{"doc":"datastar","title":"execute_script_end","content":"pub fn execute_script_end(config: ExecuteScriptConfig) -&gt; Event\n\nSynonyms:\ndatastar.execute_script_end\ndatastar execute_script_end","url":"datastar.html#execute_script_end"},{"doc":"datastar","title":"execute_script_event_id","content":"pub fn execute_script_event_id(\n  config: ExecuteScriptConfig,\n  value: String,\n) -&gt; ExecuteScriptConfig\n \n ...\n |&gt; execute_script_event_id(&quot;123&quot;)\n \n Generates:\n text\n id: 123\n \nSynonyms:\ndatastar.execute_script_event_id\ndatastar execute_script_event_id","url":"datastar.html#execute_script_event_id"},{"doc":"datastar","title":"execute_script_retry","content":"pub fn execute_script_retry(\n  config: ExecuteScriptConfig,\n  value: Int,\n) -&gt; ExecuteScriptConfig\n \n |&gt; execute_script_retry(3000),\n \n Generates:\n text\n retry: 3000\n \nSynonyms:\ndatastar.execute_script_retry\ndatastar execute_script_retry","url":"datastar.html#execute_script_retry"},{"doc":"datastar","title":"merge_fragments","content":"pub fn merge_fragments(\n  fragments fragments: String,\n) -&gt; MergeFragmentConfig\n Event to send new fragments to the client\n\n \n merge_fragments(&quot;&lt;span&gt;1&lt;/span&gt;&quot;)\n |&gt; merge_fragments_selector(&quot;#feed&quot;)\n |&gt; merge_fragments_end\n \n Generates:\n text\n event: datastar-merge-fragments\n data: selector #feed\n data: fragments &lt;span&gt;1&lt;/span&gt;\n\n \nSynonyms:\ndatastar.merge_fragments\ndatastar merge_fragments","url":"datastar.html#merge_fragments"},{"doc":"datastar","title":"merge_fragments_end","content":"pub fn merge_fragments_end(config: MergeFragmentConfig) -&gt; Event\n\nSynonyms:\ndatastar.merge_fragments_end\ndatastar merge_fragments_end","url":"datastar.html#merge_fragments_end"},{"doc":"datastar","title":"merge_fragments_event_id","content":"pub fn merge_fragments_event_id(\n  config: MergeFragmentConfig,\n  value: String,\n) -&gt; MergeFragmentConfig\n \n |&gt; merge_fragments_event_id(&quot;123&quot;),\n \n Generates:\n text\n id: 123\n \nSynonyms:\ndatastar.merge_fragments_event_id\ndatastar merge_fragments_event_id","url":"datastar.html#merge_fragments_event_id"},{"doc":"datastar","title":"merge_fragments_merge_mode","content":"pub fn merge_fragments_merge_mode(\n  config: MergeFragmentConfig,\n  value: MergeMode,\n) -&gt; MergeFragmentConfig\n \n |&gt; merge_fragments_merge_mode(MergeMode.Inner),\n \n Generates:\n text\n data: mergeMode inner\n \nSynonyms:\ndatastar.merge_fragments_merge_mode\ndatastar merge_fragments_merge_mode","url":"datastar.html#merge_fragments_merge_mode"},{"doc":"datastar","title":"merge_fragments_retry","content":"pub fn merge_fragments_retry(\n  config: MergeFragmentConfig,\n  value: Int,\n) -&gt; MergeFragmentConfig\n \n |&gt; merge_fragments_retry(3000),\n \n Generates:\n text\n retry: 3000\n \nSynonyms:\ndatastar.merge_fragments_retry\ndatastar merge_fragments_retry","url":"datastar.html#merge_fragments_retry"},{"doc":"datastar","title":"merge_fragments_selector","content":"pub fn merge_fragments_selector(\n  config: MergeFragmentConfig,\n  value: String,\n) -&gt; MergeFragmentConfig\n \n |&gt; merge_fragments_selector(&quot;#feed&quot;),\n \n Generates:\n text\n data: selector #feed\n \nSynonyms:\ndatastar.merge_fragments_selector\ndatastar merge_fragments_selector","url":"datastar.html#merge_fragments_selector"},{"doc":"datastar","title":"merge_fragments_settle_duration","content":"pub fn merge_fragments_settle_duration(\n  config: MergeFragmentConfig,\n  value: Int,\n) -&gt; MergeFragmentConfig\n\nSynonyms:\ndatastar.merge_fragments_settle_duration\ndatastar merge_fragments_settle_duration","url":"datastar.html#merge_fragments_settle_duration"},{"doc":"datastar","title":"merge_fragments_view_transition","content":"pub fn merge_fragments_view_transition(\n  config: MergeFragmentConfig,\n  value: Bool,\n) -&gt; MergeFragmentConfig\n\nSynonyms:\ndatastar.merge_fragments_view_transition\ndatastar merge_fragments_view_transition","url":"datastar.html#merge_fragments_view_transition"},{"doc":"datastar","title":"merge_signals","content":"pub fn merge_signals(signals: String) -&gt; MergeSignalsConfig\n Generate a `datastar-merge-signals` event\n\n \n merge_signals(&quot;{\\&quot;output\\&quot;:\\&quot;Output Test\\&quot;}&quot;)\n |&gt; merge_signals_end\n \n Generates:\n text\n event: datastar-merge-signals\n data: signals {\\&quot;output\\&quot;:\\&quot;Output Test\\&quot;}\n\n \nSynonyms:\ndatastar.merge_signals\ndatastar merge_signals","url":"datastar.html#merge_signals"},{"doc":"datastar","title":"merge_signals_end","content":"pub fn merge_signals_end(config: MergeSignalsConfig) -&gt; Event\n\nSynonyms:\ndatastar.merge_signals_end\ndatastar merge_signals_end","url":"datastar.html#merge_signals_end"},{"doc":"datastar","title":"merge_signals_event_id","content":"pub fn merge_signals_event_id(\n  config: MergeSignalsConfig,\n  value: String,\n) -&gt; MergeSignalsConfig\n \n ...\n |&gt; merge_signals_event_id(&quot;123&quot;)\n \n Generates:\n text\n id: 123\n \nSynonyms:\ndatastar.merge_signals_event_id\ndatastar merge_signals_event_id","url":"datastar.html#merge_signals_event_id"},{"doc":"datastar","title":"merge_signals_only_if_missing","content":"pub fn merge_signals_only_if_missing(\n  config: MergeSignalsConfig,\n  value: Bool,\n) -&gt; MergeSignalsConfig\n \n |&gt; merge_signals_only_if_missing(True),\n \n Generates:\n text\n data: onlyIfMissing true\n \nSynonyms:\ndatastar.merge_signals_only_if_missing\ndatastar merge_signals_only_if_missing","url":"datastar.html#merge_signals_only_if_missing"},{"doc":"datastar","title":"merge_signals_retry","content":"pub fn merge_signals_retry(\n  config: MergeSignalsConfig,\n  value: Int,\n) -&gt; MergeSignalsConfig\n \n |&gt; merge_signals_retry(3000),\n \n Generates:\n text\n retry: 3000\n \nSynonyms:\ndatastar.merge_signals_retry\ndatastar merge_signals_retry","url":"datastar.html#merge_signals_retry"},{"doc":"datastar","title":"remove_fragments","content":"pub fn remove_fragments(\n  selector: String,\n) -&gt; RemoveFragmentsConfig\n Event to remove fragments on the client\n\n \n remove_fragments(&quot;#feed&quot;)\n |&gt; remove_fragments_end\n \n Generates:\n text\n event: datastar-remove-fragments\n data: selector #feed\n\n \nSynonyms:\ndatastar.remove_fragments\ndatastar remove_fragments","url":"datastar.html#remove_fragments"},{"doc":"datastar","title":"remove_fragments_end","content":"pub fn remove_fragments_end(\n  config: RemoveFragmentsConfig,\n) -&gt; Event\n\nSynonyms:\ndatastar.remove_fragments_end\ndatastar remove_fragments_end","url":"datastar.html#remove_fragments_end"},{"doc":"datastar","title":"remove_fragments_event_id","content":"pub fn remove_fragments_event_id(\n  config: RemoveFragmentsConfig,\n  value: String,\n) -&gt; RemoveFragmentsConfig\n \n |&gt; remove_fragments_event_id(&quot;123&quot;),\n \n Generates:\n text\n id: 123\n \nSynonyms:\ndatastar.remove_fragments_event_id\ndatastar remove_fragments_event_id","url":"datastar.html#remove_fragments_event_id"},{"doc":"datastar","title":"remove_fragments_retry","content":"pub fn remove_fragments_retry(\n  config: RemoveFragmentsConfig,\n  value: Int,\n) -&gt; RemoveFragmentsConfig\n \n |&gt; remove_fragments_retry(3000),\n \n Generates:\n text\n retry: 3000\n \nSynonyms:\ndatastar.remove_fragments_retry\ndatastar remove_fragments_retry","url":"datastar.html#remove_fragments_retry"},{"doc":"datastar","title":"remove_fragments_settle_duration","content":"pub fn remove_fragments_settle_duration(\n  config: RemoveFragmentsConfig,\n  value: Int,\n) -&gt; RemoveFragmentsConfig\n\nSynonyms:\ndatastar.remove_fragments_settle_duration\ndatastar remove_fragments_settle_duration","url":"datastar.html#remove_fragments_settle_duration"},{"doc":"datastar","title":"remove_fragments_view_transition","content":"pub fn remove_fragments_view_transition(\n  config: RemoveFragmentsConfig,\n  value: Bool,\n) -&gt; RemoveFragmentsConfig\n\nSynonyms:\ndatastar.remove_fragments_view_transition\ndatastar remove_fragments_view_transition","url":"datastar.html#remove_fragments_view_transition"},{"doc":"datastar","title":"remove_signals","content":"pub fn remove_signals(\n  signals: List(String),\n) -&gt; RemoveSignalsConfig\n Generate a `datastar-remove-signals` event\n\n \n remove_signals([&quot;user.name&quot;, &quot;user.email&quot;])\n |&gt; remove_signals_end\n \n Generates:\n text\n event: datastar-remove-signals\n data: paths user.name\n data: paths user.email\n\n \nSynonyms:\ndatastar.remove_signals\ndatastar remove_signals","url":"datastar.html#remove_signals"},{"doc":"datastar","title":"remove_signals_end","content":"pub fn remove_signals_end(config: RemoveSignalsConfig) -&gt; Event\n\nSynonyms:\ndatastar.remove_signals_end\ndatastar remove_signals_end","url":"datastar.html#remove_signals_end"},{"doc":"datastar","title":"remove_signals_event_id","content":"pub fn remove_signals_event_id(\n  config: RemoveSignalsConfig,\n  value: String,\n) -&gt; RemoveSignalsConfig\n \n ...\n |&gt; remove_signals_event_id(&quot;123&quot;)\n \n Generates:\n text\n id: 123\n \nSynonyms:\ndatastar.remove_signals_event_id\ndatastar remove_signals_event_id","url":"datastar.html#remove_signals_event_id"},{"doc":"datastar","title":"remove_signals_retry","content":"pub fn remove_signals_retry(\n  config: RemoveSignalsConfig,\n  value: Int,\n) -&gt; RemoveSignalsConfig\n \n |&gt; remove_signals_retry(3000),\n \n Generates:\n text\n retry: 3000\n \nSynonyms:\ndatastar.remove_signals_retry\ndatastar remove_signals_retry","url":"datastar.html#remove_signals_retry"},{"doc":"datastar","title":"datastar","content":"","url":"datastar.html"}]);